@@ -5,7 +5,7 @@ import sys
 import typing as t
 import uuid
 
-from globus_sdk.scopes import MutableScope
+from globus_sdk.scopes import MutableScope, Scope
 
 if sys.version_info < (3, 8):
     from typing_extensions import Protocol
@@ -21,7 +21,8 @@ DateLike = t.Union[str, datetime.datetime]
 ScopeCollectionType = t.Union[
     str,
     MutableScope,
-    t.Iterable[t.Union[str, MutableScope]],
+    Scope,
+    t.Iterable[t.Union[str, MutableScope, Scope]],
 ]
 
 
