@@ -1,3 +1,4 @@
+from ._normalize import scopes_to_str
 from .builder import ScopeBuilder
 from .data import (
     AuthScopes,
@@ -10,11 +11,16 @@ from .data import (
     TimerScopes,
     TransferScopes,
 )
+from .errors import ScopeCycleError, ScopeParseError
+from .representation import Scope
 from .scope_definition import MutableScope
 
 __all__ = (
     "ScopeBuilder",
     "MutableScope",
+    "Scope",
+    "ScopeParseError",
+    "ScopeCycleError",
     "GCSCollectionScopeBuilder",
     "GCSEndpointScopeBuilder",
     "AuthScopes",
@@ -24,4 +30,5 @@ __all__ = (
     "SearchScopes",
     "TimerScopes",
     "TransferScopes",
+    "scopes_to_str",
 )
