@@ -1,5 +1,12 @@
 from globus_sdk.tokenstorage.base import FileAdapter, StorageAdapter
 from globus_sdk.tokenstorage.file_adapters import SimpleJSONFileAdapter
+from globus_sdk.tokenstorage.memory_adapter import MemoryAdapter
 from globus_sdk.tokenstorage.sqlite_adapter import SQLiteAdapter
 
-__all__ = ("SimpleJSONFileAdapter", "SQLiteAdapter", "StorageAdapter", "FileAdapter")
+__all__ = (
+    "SimpleJSONFileAdapter",
+    "SQLiteAdapter",
+    "StorageAdapter",
+    "FileAdapter",
+    "MemoryAdapter",
+)
